<?php

/**
 * Plugin Name: Addify Pdf invoices & packing slip for wocommerce
 * Plugin URI: https://addify.co/
 * Description: PDF Invoices attaches a fully customizable PDF invoice to a paid or completed order and other WooCommerce emails.
 * Version: 1.0.0
 * Author: Addify
 * Developed By: Addify
 * Author URI: https://addify.co/
 * Support: https://addify.co/
 * Domain Path: /languages
 * TextDomain : af_pdf_invoices
 *
 * @package :Pdf invoices for WooCommerce
/**
 * Define class.
 */
if (!defined('ABSPATH')) {
	exit;
}
if (!is_multisite()) {

	if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')), true)) {

		function af_pdf_invoices_check() {
			// Deactivate the plugin.
			deactivate_plugins(__FILE__);
			?>
			<div id="message" class="error">
				<p>
					<strong>
						<?php esc_html_e('Addify Pdf invoices for WooCommerce  . WooCommerce plugin must be active in order to activate it.', 'af_pdf_invoices'); ?>
					</strong>
				</p>
			</div>;
			<?php
		}
		add_action('admin_notices', 'af_pdf_invoices_check');
	}
}
class AF_P_D_F_I_Main {


	public function __construct() {

		$this->pdfi_global_constents_vars();

		add_action('wp_loaded', array( $this, 'pdfi_domain' ));

		include PDF_PLUGIN_DIR . 'includes/general.php';
		register_activation_hook(__FILE__, array( $this, 'addify_create_folders_and_files' ));

		if (is_admin()) {
			include PDF_PLUGIN_DIR . 'includes/admin/class_af_p_d_f_i_admin.php';
		}
		include PDF_PLUGIN_DIR . 'includes/front/class_af_p_d_f_front.php';
	}
	public function addify_create_folders_and_files() {

		$af_invoice_pdf_heading = get_option('af_invoice_pdf_heading');

		if (empty($af_invoice_pdf_heading)) {
			update_option('af_invoice_pdf_heading', 'Invoice');
		}
		$af_invoices_display_email_address = get_option('af_invoices_display_email_address');

		if (empty($af_invoices_display_email_address)) {
			update_option('af_invoices_display_email_address', 'yes');
		}

		$af_invoices_vat_number = get_option('af_invoices_vat_number');

		if (empty($af_invoices_vat_number)) {
			update_option('af_invoices_vat_number', 'U12345678');
		}

		$af_invoices_order_date = get_option('af_invoices_order_date');
		if (empty($af_invoices_order_date)) {
			update_option('af_invoices_order_date', 'yes');
		}
		$af_invoices_pdf_shipping_date = get_option('af_invoices_pdf_shipping_date');
		if (empty($af_invoices_pdf_shipping_date)) {
			update_option('af_invoices_pdf_shipping_date', 'yes');
		}
		$af_invoices_pdf_header_color = get_option('af_invoices_pdf_header_color');
		if (empty($af_invoices_pdf_header_color)) {
			update_option('af_invoices_pdf_header_color', '#ffffff');
		}
		$af_invoices_pdf_header_background_color = get_option('af_invoices_pdf_header_background_color');
		if (empty($af_invoices_pdf_header_background_color)) {
			update_option('af_invoices_pdf_header_background_color', '#bd8bbe');
		}
		$af_invoices_pdf_footer_background_color = get_option('af_invoices_pdf_footer_background_color');
		if (empty($af_invoices_pdf_footer_background_color)) {
			update_option('af_invoices_pdf_footer_background_color', '#f8acac');
		}
		$af_invoices_pdf_footer_text_color = get_option('af_invoices_pdf_footer_text_color');
		if (empty($af_invoices_pdf_footer_text_color)) {
			update_option('af_invoices_pdf_footer_text_color', '#ffffff');
		}
		$af_invoices_pdf_order_table_back_color = get_option('af_invoices_pdf_order_table_back_color');
		if (empty($af_invoices_pdf_order_table_back_color)) {
			update_option('af_invoices_pdf_order_table_back_color', '#9274af');
		}

		$af_invoices_pdf_order_table_color = get_option('af_invoices_pdf_order_table_color');
		if (empty($af_invoices_pdf_order_table_color)) {
			update_option('af_invoices_pdf_order_table_color', '#ffffff');
		}
		$default_order_statuses = array( 'wc-processing', 'wc-completed' );
		add_option('order_statuses', $default_order_statuses);

		$default_emails = array( 'wc-completed', 'wc-new_order' );
		update_option('af_invoices_pdf_select_email', $default_emails);

		$af_pdf_invoices_credit_note_heading = get_option('af_pdf_invoices_credit_note_heading');
		if (empty($af_pdf_invoices_credit_note_heading)) {
			update_option('af_pdf_invoices_credit_note_heading', 'credit note');
		}
		$af_pdf_invoices_packing_slip_headeing = get_option('af_pdf_invoices_packing_slip_headeing');
		if (empty($af_pdf_invoices_packing_slip_headeing)) {
			update_option('af_pdf_invoices_packing_slip_headeing', 'Packing Slip');
		}







		$base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip';
		$invoices_dir = $base_dir . '/pdf-invoices';
		$packing_slip_dir = $base_dir . '/packing-slip';
		$credit_note_dir = $base_dir . '/credit-note';

		if (!file_exists($base_dir)) {
			mkdir($base_dir, 0755, true);
		}


		if (!file_exists($invoices_dir)) {
			mkdir($invoices_dir, 0755, true);
		}


		if (!file_exists($packing_slip_dir)) {
			mkdir($packing_slip_dir, 0755, true);
		}

		if (!file_exists($credit_note_dir)) {
			mkdir($credit_note_dir, 0755, true);
		}
	}


	public function pdfi_global_constents_vars() {

		if (!defined('PDF_URL')) {
			define('PDFI_URL', plugin_dir_url(__FILE__));
		}
		if (!defined('PDF_BASENAME')) {
			define('PDFI_BASENAME', plugin_basename(__FILE__));
		}

		if (!defined('PDF_PLUGIN_DIR')) {
			define('PDF_PLUGIN_DIR', plugin_dir_path(__FILE__));
		}
	}

	public function pdfi_domain() {

		if (function_exists('load_plugin_textdomain')) {
			load_plugin_textdomain('af_pdf_invoices', false, dirname(plugin_basename(__FILE__)) . '/languages/');
		}
	}
}
if (class_exists('AF_P_D_F_I_Main')) {
	new AF_P_D_F_I_Main();
}
