<?php
require PDF_PLUGIN_DIR . 'vendor/autoload.php';
use Dompdf\Dompdf;
use Dompdf\Options;
use Dompdf\FontMetrics;
if (!defined('WPINC')) {
	die;
}

class Addify_P_D_F_I_Front {







	public function __construct() {


		add_action('wp_enqueue_scripts', array( $this, 'af_pdf_invoices_front_assests' ), 10);
		add_filter('woocommerce_account_orders_columns', array( $this, 'add_pdf_download_column' ), 10, 2);
		add_action('woocommerce_my_account_my_orders_column_pdf-download', array( $this, 'populate_pdf_download_column' ), 10, 1);
		add_action('wp_ajax_download_invoice_pdf', array( $this, 'handle_download_invoice_pdf' ));
		add_action('wp_ajax_nopriv_download_invoice_pdf', array( $this, 'handle_download_invoice_pdf' ));
		add_action('wp_ajax_download_credit_note_pdf', array( $this, 'handle_download_credit_note_pdf' ));
		add_action('wp_ajax_nopriv_download_credit_note_pdf', array( $this, 'handle_download_credit_note_pdf' ));
		add_action('woocommerce_email_attachments', array( $this, 'af_pdf_invoice_new_order_email' ), 10, 3);
	}
	
	public function af_pdf_invoice_new_order_email( $attachments, $email_id, $order ) {
		$af_invoices_pdf_select_email = (array) get_option('af_invoices_pdf_select_email');
		$af_pdf_invoices_email = array_map('strtolower', $af_invoices_pdf_select_email);
		if (in_array(strtolower('wc_email_' . $email_id), $af_pdf_invoices_email)) {

			$custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/pdf-invoices';
			$default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/pdf';
			$default_design = 'temp1.php';
			if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir)) {
				$base_dir = $default_base_dir;
			} else {
				$base_dir = $custom_base_dir;
			}
			$af_invoice_pdf_select_design = get_option('af_invoice_pdf_select_design') ? get_option('af_invoice_pdf_select_design') : $default_design;
			if (substr($af_invoice_pdf_select_design, -4) !== '.php') {
				$af_invoice_pdf_select_design .= '.php';
			}
			if (!file_exists($base_dir . '/' . $af_invoice_pdf_select_design)) {
				if (file_exists($default_base_dir . '/' . $af_invoice_pdf_select_design)) {
					$base_dir = $default_base_dir;
				} else {
					$af_invoice_pdf_select_design = $default_design;
					$base_dir = $default_base_dir;
				}
			}

			ob_start();
			include $base_dir . '/' . $af_invoice_pdf_select_design;
			$af_invoice_pdf = ob_get_clean();

			require PDF_PLUGIN_DIR . 'vendor/autoload.php';

			$options = new Options();
			$options->set('isPhpEnabled', true);
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new Dompdf($options);
			$dompdf->loadHtml($af_invoice_pdf);
			$dompdf->setPaper('A4', 'Portrait');
			$dompdf->render();

			$output = $dompdf->output();
			$basedir = wp_upload_dir()['basedir'];
			$directory = $basedir . '/addify-pdf-invoices/';
			wp_mkdir_p($directory);
			$pdf_path = $directory . 'invoice-' . $order->get_id() . '.pdf';

			if (file_exists($pdf_path)) {
				unlink($pdf_path);
			}
			file_put_contents($pdf_path, $output);
			$attachments[] = $pdf_path;

		}

		return $attachments;
	}
	public function handle_download_invoice_pdf() {
		if (!isset($_GET['order_id']) || !isset($_REQUEST['_wpnonce']) || !wp_verify_nonce(sanitize_text_field($_REQUEST['_wpnonce']), 'download_invoice_pdf')) {
			die('Invalid request');
		}


		$order_id = intval($_GET['order_id']);
		$this->generate_and_download_pdf_invoice($order_id);
		exit;
	}

	public function generate_and_download_pdf_invoice( $order_id ) {
       require PDF_PLUGIN_DIR . 'vendor/autoload.php';


		$order = wc_get_order($order_id);
		if (!$order) {
			return;
		}

		$custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/pdf-invoices';
		$default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/pdf';
		$default_design = 'temp1.php';

		if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir)) {
			$base_dir = $default_base_dir;
		} else {
			$base_dir = $custom_base_dir;
		}

		$af_invoice_pdf_select_design = get_option('af_invoice_pdf_select_design') ? get_option('af_invoice_pdf_select_design') : $default_design;

		if (substr($af_invoice_pdf_select_design, -4) !== '.php') {
			$af_invoice_pdf_select_design .= '.php';
		}

		if (!file_exists($base_dir . '/' . $af_invoice_pdf_select_design)) {
			if (file_exists($default_base_dir . '/' . $af_invoice_pdf_select_design)) {
				$base_dir = $default_base_dir;
			} else {
				$af_invoice_pdf_select_design = $default_design;
				$base_dir = $default_base_dir;
			}
		}

		ob_start();
		include $base_dir . '/' . $af_invoice_pdf_select_design;
		$af_invoice_pdf = ob_get_clean();

		$options = new Options();
			$options->set('isPhpEnabled', 'true');
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new Dompdf($options);
		$dompdf->loadHtml($af_invoice_pdf);
		$dompdf->setPaper('A4', 'Portrait');
		$dompdf->render();
		$dompdf->stream('invoice-' . $order_id . '.pdf', array( 'Attachment' => 1 ));
	}

	public function handle_download_credit_note_pdf() {
		if (!isset($_GET['order_id']) || !isset($_REQUEST['_wpnonce']) || !wp_verify_nonce(sanitize_text_field($_REQUEST['_wpnonce']), 'download_credit_note_pdf')) {
			die('Invalid request');
		}


		$order_id = intval($_GET['order_id']);
		$this->generate_and_download_credit_note_pdf($order_id);
		exit;
	}

public function generate_and_download_credit_note_pdf( $order_id ) {

    if (!isset($_REQUEST['_wpnonce']) || !wp_verify_nonce(sanitize_text_field($_REQUEST['_wpnonce']), 'download_credit_note_pdf')) {
        die('Invalid request');
    }

    require_once PDF_PLUGIN_DIR . 'vendor/autoload.php'; 

    $order = wc_get_order($order_id);
    if (!$order) {
        return;
    }

  
    $af_pdf_invoices_credit_note_option = get_option('af_pdf_invoices_credit_note_option', 'default');

 
    $default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/credit-note';

    if ( 'customize' ==  $af_pdf_invoices_credit_note_option ) {
      
        $af_credit_note_pdf_select_design = get_option('af_pdf_invoices_credit_note_design');
       
        if (substr($af_credit_note_pdf_select_design, -4) !== '.php') {
            $af_credit_note_pdf_select_design .= '.php';
        }

   
        $base_dir = $default_base_dir;
        $template_file = $base_dir . '/' . $af_credit_note_pdf_select_design;
        
        if (!file_exists($template_file)) {
            die('Credit note template not found.');
        }

    
        ob_start();
        include $template_file;
        $af_credit_note_pdf = ob_get_clean();

      
        $options = new Options();
        $options->set('isPhpEnabled', true);
        $options->set('isRemoteEnabled', true);
        $options->set('defaultPaperSize', 'letter');
        $options->set('isHtml5ParserEnabled', true);

        $dompdf = new Dompdf($options);
        $dompdf->loadHtml($af_credit_note_pdf);
        $dompdf->setPaper('A4', 'portrait');
        $dompdf->render();

        $dompdf->stream('credit-note-' . $order_id . '.pdf', array('Attachment' => 1));

    } else {
    
        $this->generate_and_download_pdf_invoice( $order_id );
    }
}










	public function populate_pdf_download_column( $order ) {
		$order_status = 'wc-' . str_replace('wc-', '', $order->get_status());

		$af_invoices_order_statuses = get_option('order_statuses');



		if ('wc-refunded' === $order_status) {
			$download_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_credit_note_pdf&order_id=' . $order->get_id()), 'download_credit_note_pdf');
			echo '<a href="' . esc_url($download_url) . '">' . esc_html__('Download Credit Note', 'woocommerce') . '</a>';
		}

		if (in_array($order_status, $af_invoices_order_statuses)) {
			$download_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_invoice_pdf&order_id=' . $order->get_id()), 'download_invoice_pdf');
			echo '<a href="' . esc_url($download_url) . '">' . esc_html__('Download PDF Invoice', 'woocommerce') . '</a>';

		}
	}


	public function add_pdf_download_column( $columns ) {
		$new_columns = array();

		foreach ($columns as $key => $column) {
			$new_columns[ $key ] = $column;
			if ('order-actions' == $key) {
				$new_columns['pdf-download'] = __('Download PDF', 'woocommerce');
			}
		}

		return $new_columns;
	}

	public function af_pdf_invoices_front_assests() {
		wp_enqueue_style('af_mli_font_awesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css', false, '4.7.0', false);
	}
}

new Addify_P_D_F_I_Front();
